@@ -1,7 +1,7 @@
 #Plots all the arcs imported from an ARC file by get.arcdata
 
 #New: T for new plots
-plotarc<-function(arc, new=T)
+plotarc<-function(arc, new=TRUE)
 {
 
 #We only need the list of arcs, not the dataframe with the other data
@@ -9,7 +9,7 @@ arc<-arc[[2]]
 
 ll<-length(arc)
 
-if(new==T)
+if(new==TRUE)
 {
 #Calculate the boundary
 
